@@ -4,21 +4,28 @@
 # @Date  : 2025/08/21/14:44
 import base64
 import hashlib
-
 import excel2img
-from reportlab.pdfgen import canvas
-from reportlab.lib.utils import ImageReader
 import pymysql
-import pandas as pd
-from functools import wraps
 import time
 import re
 import datetime
-from tableauserverclient import Server, TableauAuth, Pager
 import os
 import traceback
 import json
 import requests
+import ssl
+import smtplib
+from tableauserverclient import Server, TableauAuth, Pager
+from email.mime.multipart import MIMEMultipart
+from email.mime.text import MIMEText
+from email.mime.base import MIMEBase
+from email.mime.image import MIMEImage
+from email import encoders
+import pandas as pd
+from functools import wraps
+from reportlab.pdfgen import canvas
+from reportlab.lib.utils import ImageReader
+
 
 # ============ 新增：PDF 二次处理 ============
 try:
@@ -545,3 +552,109 @@ class AllTool:
             except Exception:
                 pass
         return results
+
+    @staticmethod
+    def send_email(sender,area_email,filename,subject,attachment,html_body,tf_attached,cc_list=None,image_path=None):
+        """
+        send_email
+        :param area_email: （str or list）
+        :param sender:dir
+        :param subject: main_title
+        :param attachment:attachment filename
+        :param filename: attachment filepath
+        :param tf_attached: tf_attached
+        :param cc_list: cc_list
+        :param image_path: image_path
+        """
+        port = sender['port']
+        smtp_server = sender['smtp_server']
+        sender_email = sender['sender_email']
+        password = sender['password']
+
+        to_list = area_email if isinstance(area_email,list) else [area_email]
+        to_str = ', '.join(to_list)
+
+        cc_list = cc_list or []
+        if isinstance(cc_list,str):
+            cc_list = [cc_list]
+        cc_str = ', '.join(cc_list)
+
+        message = MIMEMultipart('related')
+        message['From'] = sender_email
+        message['To'] = to_str
+        if cc_list:
+            message['Cc'] = cc_str
+        message['Subject'] = subject
+        html_body = html_body
+        part_html = MIMEText(html_body,'html','utf-8')
+        message.attach(part_html)
+
+        if image_path and os.path.exists(image_path):
+            try:
+                with open(image_path,'rb') as img_file:
+                    img = MIMEImage(img_file.read())
+                img.add_header('Content-ID','<image>')
+                img.add_header('Content-Disposition','inline',filename=os.path.basename(image_path))
+                message.attach(img)
+                print(f"🖼️  已内嵌图片：{image_path}")
+            except Exception as e:
+                print(f"❌ 嵌入图片失败：{e}")
+        else:
+            if image_path:
+                print(f"❌ 内嵌图片文件不存在：{image_path}")
+
+        if tf_attached:
+            if not os.path.exists(filename):
+                print(f"❌ 附件文件不存在：{filename}")
+                return
+            try:
+                with open(filename,'rb') as f:
+                    part = MIMEBase('application','octet-stream')
+                    part.set_payload(f.read())
+                encoders.encode_base64(part)
+                safe_filename = attachment
+                part.add_header(
+                    'Content-Disposition',
+                    'attachment',
+                    filename=safe_filename
+                )
+                message.attach(part)
+                print(f"📎 已添加附件：{filename}")
+            except Exception as e:
+                print(f"❌ 添加附件失败：{e}")
+                return
+
+        all_recipients = to_list + cc_list
+        context = ssl.create_default_context()
+        context.check_hostname = False
+        context.verify_mode = ssl.CERT_NONE
+        try:
+            with smtplib.SMTP_SSL(smtp_server,port,context=context) as server:
+                server.login(sender_email,password)
+                print("✅ 登录邮件服务器成功")
+                server.sendmail(sender_email,all_recipients,message.as_string())
+                print(f"✅ 邮件已发送至：收件人={to_str}, 抄送={cc_str if cc_list else '无'}")
+        except Exception as e:
+            print(f"❌ 发送邮件失败：{e}")
+
+class ExFormat:
+
+    @staticmethod
+    def bf(workbook):
+        return workbook.add_format(
+            {'bold':True,'font_name':'Microsoft YaHei','align':'center','valign':'vcenter','border':1,'bg_color':'#ffc000',
+             'text_wrap':True})
+
+    @staticmethod
+    def tf(workbook):
+        return workbook.add_format({'border':1,'font_name':'Microsoft Yahei','num_format':'#,##0.0'})
+
+    @staticmethod
+    def pf(workbook):
+        return workbook.add_format({'border':1,'font_name':'Microsoft Yahei','num_format':'0.0%'})
+
+    @staticmethod
+    def baf():
+        return {
+            'type':'data_bar', 'bar_color':'#63C384', 'bar_only':False, 'bar_solid':True, 'bar_negative_color':'#ff0000', 'bar_direction':'left', 
+        }
